"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addOptions = exports.getOptions = void 0;
const path = require("path");
const typedoc_1 = require("typedoc");
const DEFAULT_PLUGIN_OPTIONS = {
    out: 'api',
    hideBreadcrumbs: true,
    plugin: ['typedoc-plugin-markdown'],
    sidebar: {
        parentCategory: 'none',
        fullNames: false,
        sidebarFile: 'typedoc-sidebar.js',
        sidebarPath: '',
    },
    watch: false,
};
const getOptions = (opts) => {
    let options = {
        ...DEFAULT_PLUGIN_OPTIONS,
        ...opts,
    };
    if (opts.sidebar === null) {
        options = { ...options, sidebar: null };
    }
    else {
        const sidebar = {
            ...DEFAULT_PLUGIN_OPTIONS.sidebar,
            ...opts.sidebar,
        };
        options = {
            ...options,
            sidebar: {
                ...sidebar,
                sidebarPath: path.resolve(sidebar.sidebarFile),
            },
        };
    }
    if (opts.plugin) {
        options = {
            ...options,
            plugin: [...DEFAULT_PLUGIN_OPTIONS.plugin, ...opts.plugin],
        };
    }
    options = {
        ...options,
    };
    return options;
};
exports.getOptions = getOptions;
const addOptions = (app) => {
    app.options.addReader(new typedoc_1.TypeDocReader());
    app.options.addReader(new typedoc_1.TSConfigReader());
    app.options.addDeclaration({
        name: 'sidebar',
        type: typedoc_1.ParameterType.Mixed,
    });
};
exports.addOptions = addOptions;
