"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typedocPlugin = void 0;
const typedoc_1 = require("typedoc");
const front_matter_1 = require("./front-matter");
const options_1 = require("./options");
const sidebar_1 = require("./sidebar");
let app;
let project;
const done = false;
const typedocPlugin = (opts, ctx) => {
    const options = options_1.getOptions(opts);
    return {
        name: 'vuepress-plugin-typedoc',
        async ready() {
            if (!done) {
                app = new typedoc_1.Application();
                const sourceDir = ctx.sourceDir;
                const outputDirectory = sourceDir + '/' + options.out;
                options_1.addOptions(app);
                app.bootstrap(options);
                app.renderer.addComponent('fm', new front_matter_1.FrontMatterComponent(app.renderer));
                project = app.convert();
                if (!project) {
                    return;
                }
                await app.generateDocs(project, outputDirectory);
                if (options.watch) {
                    app.convertAndWatch(async (project) => {
                        await app.generateDocs(project, outputDirectory);
                    });
                }
            }
        },
        async enhanceAppFiles() {
            if (done || !options.sidebar) {
                return;
            }
            const theme = app.renderer.theme;
            const navigation = theme.getNavigation(project);
            return {
                name: 'typedoc-sidebar',
                content: `export default ({ siteData, options }) => {
          siteData.themeConfig.sidebarDepth = 0;
          siteData.themeConfig.sidebar = Object.assign({},siteData.themeConfig.sidebar,${JSON.stringify({
                    [`/${options.out}/`]: sidebar_1.getSidebarJson(navigation, options.out, options.sidebar),
                })});
        }`,
            };
        },
    };
};
exports.typedocPlugin = typedocPlugin;
